@@ -15,23 +15,39 @@
 
 import json
 
+from datetime import datetime
+
+datetime.now().strftime("%Y_%m_%d-%I_%M_%S_%p")
+
+
+#####################################################################
+
 from . import get_version
 
 #####################################################################
+def default_json( t ) :
+    return f'{t}'
 
-def write( msg_raw ) :
+def write_msg( msg_raw ) :
 
     msg = msg_raw
-    if(isinstance(msg,list)):
-        msg=msg.tostring()
-    if(isinstance(msg,dict)):
-        msg=json.dumps(msg)
+    
+    if( isinstance( msg , list ) ) :
+        msg = ",".join( map( str , msg ) )
+    
+    if( isinstance( msg , dict ) ) :
+        msg = json.dumps( msg , default = default_json )
 
-    with open( "/tmp/pyespremclient.log" , "a+" ) as log :
-        log.write( msg + "\n" )
+
+    if( isinstance( msg , ( int , float , bool ) ) ) :
+        msg = str( msg )
+
+    msg = datetime.now( ).strftime( "%Y_%m_%d-%I_%M_%S_%p" ) + " " + msg
+    with open( "/tmp/pyespremclient.log" , "a+" , 1 ) as log_file :
+        log_file.write( msg + "\n" )
 
 #####################################################################
 
-write( "PYESPREMCLIENT" + get_version( ) )
+write_msg( "PYESPREMCLIENT " + get_version( ) )
 
     
\ No newline at end of file
